Struct use_github_api::GithubClientBuilder [−][src]
#[non_exhaustive]pub struct GithubClientBuilder<'a> { /* fields omitted */ }
A GithubClient builder.
Allows building a GithubClient while still setting options like the base URL and auth token. Only useful when either the auth or enterprise feature enabled.
Examples
ⓘ
use use_github_api::{GithubClient, GithubClientBuilder}; // If `enterprise` is enabled let client = GithubClientBuilder::new().auth("adS*lkjha(&W3").base_url("https://gh.enterprise.org/api/v3").build().unwrap(); // If `enterprise` is not enabled let client = GithubClientBuilder::new().auth("ghp_kajshdkja").build().unwrap();
Implementations
impl<'a> GithubClientBuilder<'a>[src]
impl<'a> GithubClientBuilder<'a>[src]Trait Implementations