Struct use_github_api::users::Users [−][src]
#[non_exhaustive]pub struct Users<'a> { /* fields omitted */ }
Implementations
impl<'a> Users<'a>[src]
impl<'a> Users<'a>[src]pub async fn list(
&self,
cfg: Option<Params>
) -> Result<Vec<User>, Box<dyn Error>>[src]
pub async fn list(
&self,
cfg: Option<Params>
) -> Result<Vec<User>, Box<dyn Error>>[src]Fetches a list of users.
pub async fn user(&self, username: &str) -> Result<User, Box<dyn Error>>[src]
pub async fn user(&self, username: &str) -> Result<User, Box<dyn Error>>[src]Fetches a specific user. If authenticated, it will show a few more fields. If the current authenticated user is the same as the user being fetched, a few more fields will exist.
Errors
Will error if the user does not exist.